@@ -42,6 +42,7 @@ import shutil
 from collections import MutableSet
 from contextlib import contextmanager
 import tempfile
+from fnmatch import fnmatch
 
 from calculate.lib.utils.git import Git, GitError, MTimeKeeper, NotGitError
 from calculate.lib.utils.portage import (ReposConf, EmergeLog,
@@ -317,7 +318,7 @@ class Update(MethodsInterface):
                 self.endTask()
 
         if self.clVars.Get('cl_chroot_status') == 'off':
-            emerge_running = lambda: any("/usr/bin/emerge" in x
+            emerge_running = lambda: any(fnmatch(x, "*python-exec/*/emerge*")
                                          for x in getRunCommands(True))
             if emerge_running():
                 if not wait_update:
