@@ -1480,6 +1480,21 @@ class VariableClUpdateSkipRbSet(Variable):
         self.help = _("skip reverse dependencies check")
 
 
+class VariableClUpdateRevdepRebuildSet(Variable):
+    """
+    Запустить revdep-rebuild
+    """
+    type = "bool"
+    value = "off"
+
+    opt = ["-R", "--revdep-rebuild"]
+
+    def init(self):
+        self.label = _("Run reverse dependencies check")
+        self.help = _("run reverse dependencies check")
+
+
+
 class VariableClUpdateOutdatedKernelSet(ReadonlyVariable):
     """
     Есть наличие устаревшего ядра
